# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/dubbo_proxy/v3/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from envoy.type.v3 import range_pb2 as envoy_dot_type_dot_v3_dot_range__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;envoy/extensions/filters/network/dubbo_proxy/v3/route.proto\x12/envoy.extensions.filters.network.dubbo_proxy.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a,envoy/config/route/v3/route_components.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x19\x65nvoy/type/v3/range.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xe9\x01\n\x12RouteConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tinterface\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x46\n\x06routes\x18\x05 \x03(\x0b\x32\x36.envoy.extensions.filters.network.dubbo_proxy.v3.Route:J\x9a\xc5\x88\x1e\x45\nCenvoy.config.filter.network.dubbo_proxy.v2alpha1.RouteConfiguration\"\xf3\x01\n\x05Route\x12T\n\x05match\x18\x01 \x01(\x0b\x32;.envoy.extensions.filters.network.dubbo_proxy.v3.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12U\n\x05route\x18\x02 \x01(\x0b\x32<.envoy.extensions.filters.network.dubbo_proxy.v3.RouteActionB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:=\x9a\xc5\x88\x1e\x38\n6envoy.config.filter.network.dubbo_proxy.v2alpha1.Route\"\xd5\x01\n\nRouteMatch\x12L\n\x06method\x18\x01 \x01(\x0b\x32<.envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch\x12\x35\n\x07headers\x18\x02 \x03(\x0b\x32$.envoy.config.route.v3.HeaderMatcher:B\x9a\xc5\x88\x1e=\n;envoy.config.filter.network.dubbo_proxy.v2alpha1.RouteMatch\"\xfc\x01\n\x0bRouteAction\x12\x11\n\x07\x63luster\x18\x01 \x01(\tH\x00\x12\x43\n\x11weighted_clusters\x18\x02 \x01(\x0b\x32&.envoy.config.route.v3.WeightedClusterH\x00\x12\x36\n\x0emetadata_match\x18\x03 \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata:C\x9a\xc5\x88\x1e>\n<envoy.config.filter.network.dubbo_proxy.v2alpha1.RouteActionB\x18\n\x11\x63luster_specifier\x12\x03\xf8\x42\x01\"\xd5\x04\n\x0bMethodMatch\x12\x32\n\x04name\x18\x01 \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12\x63\n\x0cparams_match\x18\x02 \x03(\x0b\x32M.envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.ParamsMatchEntry\x1a\xdc\x01\n\x17ParameterMatchSpecifier\x12\x15\n\x0b\x65xact_match\x18\x03 \x01(\tH\x00\x12\x30\n\x0brange_match\x18\x04 \x01(\x0b\x32\x19.envoy.type.v3.Int64RangeH\x00:[\x9a\xc5\x88\x1eV\nTenvoy.config.filter.network.dubbo_proxy.v2alpha1.MethodMatch.ParameterMatchSpecifierB\x1b\n\x19parameter_match_specifier\x1a\x88\x01\n\x10ParamsMatchEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x63\n\x05value\x18\x02 \x01(\x0b\x32T.envoy.extensions.filters.network.dubbo_proxy.v3.MethodMatch.ParameterMatchSpecifier:\x02\x38\x01:C\x9a\xc5\x88\x1e>\n<envoy.config.filter.network.dubbo_proxy.v2alpha1.MethodMatch\"\x85\x01\n\x1aMultipleRouteConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12Y\n\x0croute_config\x18\x04 \x03(\x0b\x32\x43.envoy.extensions.filters.network.dubbo_proxy.v3.RouteConfigurationB\xbb\x01\n=io.envoyproxy.envoy.extensions.filters.network.dubbo_proxy.v3B\nRouteProtoP\x01Zdgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/dubbo_proxy/v3;dubbo_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.dubbo_proxy.v3.route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n=io.envoyproxy.envoy.extensions.filters.network.dubbo_proxy.v3B\nRouteProtoP\001Zdgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/dubbo_proxy/v3;dubbo_proxyv3\272\200\310\321\006\002\020\002'
  _ROUTECONFIGURATION._options = None
  _ROUTECONFIGURATION._serialized_options = b'\232\305\210\036E\nCenvoy.config.filter.network.dubbo_proxy.v2alpha1.RouteConfiguration'
  _ROUTE.fields_by_name['match']._options = None
  _ROUTE.fields_by_name['match']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ROUTE.fields_by_name['route']._options = None
  _ROUTE.fields_by_name['route']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ROUTE._options = None
  _ROUTE._serialized_options = b'\232\305\210\0368\n6envoy.config.filter.network.dubbo_proxy.v2alpha1.Route'
  _ROUTEMATCH._options = None
  _ROUTEMATCH._serialized_options = b'\232\305\210\036=\n;envoy.config.filter.network.dubbo_proxy.v2alpha1.RouteMatch'
  _ROUTEACTION.oneofs_by_name['cluster_specifier']._options = None
  _ROUTEACTION.oneofs_by_name['cluster_specifier']._serialized_options = b'\370B\001'
  _ROUTEACTION._options = None
  _ROUTEACTION._serialized_options = b'\232\305\210\036>\n<envoy.config.filter.network.dubbo_proxy.v2alpha1.RouteAction'
  _METHODMATCH_PARAMETERMATCHSPECIFIER._options = None
  _METHODMATCH_PARAMETERMATCHSPECIFIER._serialized_options = b'\232\305\210\036V\nTenvoy.config.filter.network.dubbo_proxy.v2alpha1.MethodMatch.ParameterMatchSpecifier'
  _METHODMATCH_PARAMSMATCHENTRY._options = None
  _METHODMATCH_PARAMSMATCHENTRY._serialized_options = b'8\001'
  _METHODMATCH._options = None
  _METHODMATCH._serialized_options = b'\232\305\210\036>\n<envoy.config.filter.network.dubbo_proxy.v2alpha1.MethodMatch'
  _globals['_ROUTECONFIGURATION']._serialized_start=346
  _globals['_ROUTECONFIGURATION']._serialized_end=579
  _globals['_ROUTE']._serialized_start=582
  _globals['_ROUTE']._serialized_end=825
  _globals['_ROUTEMATCH']._serialized_start=828
  _globals['_ROUTEMATCH']._serialized_end=1041
  _globals['_ROUTEACTION']._serialized_start=1044
  _globals['_ROUTEACTION']._serialized_end=1296
  _globals['_METHODMATCH']._serialized_start=1299
  _globals['_METHODMATCH']._serialized_end=1896
  _globals['_METHODMATCH_PARAMETERMATCHSPECIFIER']._serialized_start=1468
  _globals['_METHODMATCH_PARAMETERMATCHSPECIFIER']._serialized_end=1688
  _globals['_METHODMATCH_PARAMSMATCHENTRY']._serialized_start=1691
  _globals['_METHODMATCH_PARAMSMATCHENTRY']._serialized_end=1827
  _globals['_MULTIPLEROUTECONFIGURATION']._serialized_start=1899
  _globals['_MULTIPLEROUTECONFIGURATION']._serialized_end=2032
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/cluster/v2alpha/outlier_detection_event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8envoy/data/cluster/v2alpha/outlier_detection_event.proto\x12\x1a\x65nvoy.data.cluster.v2alpha\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x96\x05\n\x15OutlierDetectionEvent\x12G\n\x04type\x18\x01 \x01(\x0e\x32/.envoy.data.cluster.v2alpha.OutlierEjectionTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x16secs_since_last_action\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1d\n\x0c\x63luster_name\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1d\n\x0cupstream_url\x18\x05 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12<\n\x06\x61\x63tion\x18\x06 \x01(\x0e\x32\".envoy.data.cluster.v2alpha.ActionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rnum_ejections\x18\x07 \x01(\r\x12\x10\n\x08\x65nforced\x18\x08 \x01(\x08\x12W\n\x18\x65ject_success_rate_event\x18\t \x01(\x0b\x32\x33.envoy.data.cluster.v2alpha.OutlierEjectSuccessRateH\x00\x12V\n\x17\x65ject_consecutive_event\x18\n \x01(\x0b\x32\x33.envoy.data.cluster.v2alpha.OutlierEjectConsecutiveH\x00\x12\x63\n\x1e\x65ject_failure_percentage_event\x18\x0b \x01(\x0b\x32\x39.envoy.data.cluster.v2alpha.OutlierEjectFailurePercentageH\x00\x42\x0c\n\x05\x65vent\x12\x03\xf8\x42\x01\"\xa6\x01\n\x17OutlierEjectSuccessRate\x12\"\n\x11host_success_rate\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64\x12-\n\x1c\x63luster_average_success_rate\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64\x12\x38\n\'cluster_success_rate_ejection_threshold\x18\x03 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64\"\x19\n\x17OutlierEjectConsecutive\"C\n\x1dOutlierEjectFailurePercentage\x12\"\n\x11host_success_rate\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64*\xdf\x01\n\x13OutlierEjectionType\x12\x13\n\x0f\x43ONSECUTIVE_5XX\x10\x00\x12\x1f\n\x1b\x43ONSECUTIVE_GATEWAY_FAILURE\x10\x01\x12\x10\n\x0cSUCCESS_RATE\x10\x02\x12$\n CONSECUTIVE_LOCAL_ORIGIN_FAILURE\x10\x03\x12\x1d\n\x19SUCCESS_RATE_LOCAL_ORIGIN\x10\x04\x12\x16\n\x12\x46\x41ILURE_PERCENTAGE\x10\x05\x12#\n\x1f\x46\x41ILURE_PERCENTAGE_LOCAL_ORIGIN\x10\x06* \n\x06\x41\x63tion\x12\t\n\x05\x45JECT\x10\x00\x12\x0b\n\x07UNEJECT\x10\x01\x42\xb0\x01\n(io.envoyproxy.envoy.data.cluster.v2alphaB\x1aOutlierDetectionEventProtoP\x01ZAgithub.com/envoyproxy/go-control-plane/envoy/data/cluster/v2alpha\xf2\x98\xfe\x8f\x05\x17\x12\x15\x65nvoy.data.cluster.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.cluster.v2alpha.outlier_detection_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.envoyproxy.envoy.data.cluster.v2alphaB\032OutlierDetectionEventProtoP\001ZAgithub.com/envoyproxy/go-control-plane/envoy/data/cluster/v2alpha\362\230\376\217\005\027\022\025envoy.data.cluster.v3\272\200\310\321\006\002\020\001'
  _OUTLIERDETECTIONEVENT.oneofs_by_name['event']._options = None
  _OUTLIERDETECTIONEVENT.oneofs_by_name['event']._serialized_options = b'\370B\001'
  _OUTLIERDETECTIONEVENT.fields_by_name['type']._options = None
  _OUTLIERDETECTIONEVENT.fields_by_name['type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _OUTLIERDETECTIONEVENT.fields_by_name['cluster_name']._options = None
  _OUTLIERDETECTIONEVENT.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002 \001'
  _OUTLIERDETECTIONEVENT.fields_by_name['upstream_url']._options = None
  _OUTLIERDETECTIONEVENT.fields_by_name['upstream_url']._serialized_options = b'\372B\004r\002 \001'
  _OUTLIERDETECTIONEVENT.fields_by_name['action']._options = None
  _OUTLIERDETECTIONEVENT.fields_by_name['action']._serialized_options = b'\372B\005\202\001\002\020\001'
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['host_success_rate']._options = None
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['host_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_average_success_rate']._options = None
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_average_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_success_rate_ejection_threshold']._options = None
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_success_rate_ejection_threshold']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIEREJECTFAILUREPERCENTAGE.fields_by_name['host_success_rate']._options = None
  _OUTLIEREJECTFAILUREPERCENTAGE.fields_by_name['host_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _globals['_OUTLIEREJECTIONTYPE']._serialized_start=1172
  _globals['_OUTLIEREJECTIONTYPE']._serialized_end=1395
  _globals['_ACTION']._serialized_start=1397
  _globals['_ACTION']._serialized_end=1429
  _globals['_OUTLIERDETECTIONEVENT']._serialized_start=242
  _globals['_OUTLIERDETECTIONEVENT']._serialized_end=904
  _globals['_OUTLIEREJECTSUCCESSRATE']._serialized_start=907
  _globals['_OUTLIEREJECTSUCCESSRATE']._serialized_end=1073
  _globals['_OUTLIEREJECTCONSECUTIVE']._serialized_start=1075
  _globals['_OUTLIEREJECTCONSECUTIVE']._serialized_end=1100
  _globals['_OUTLIEREJECTFAILUREPERCENTAGE']._serialized_start=1102
  _globals['_OUTLIEREJECTFAILUREPERCENTAGE']._serialized_end=1169
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/config_source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import grpc_service_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%envoy/api/v2/core/config_source.proto\x12\x11\x65nvoy.api.v2.core\x1a$envoy/api/v2/core/grpc_service.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa0\x04\n\x0f\x41piConfigSource\x12\x46\n\x08\x61pi_type\x18\x01 \x01(\x0e\x32*.envoy.api.v2.core.ApiConfigSource.ApiTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x46\n\x15transport_api_version\x18\x08 \x01(\x0e\x32\x1d.envoy.api.v2.core.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rcluster_names\x18\x02 \x03(\t\x12\x35\n\rgrpc_services\x18\x04 \x03(\x0b\x32\x1e.envoy.api.v2.core.GrpcService\x12\x30\n\rrefresh_delay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12<\n\x0frequest_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x41\n\x13rate_limit_settings\x18\x06 \x01(\x0b\x32$.envoy.api.v2.core.RateLimitSettings\x12&\n\x1eset_node_on_first_message_only\x18\x07 \x01(\x08\"T\n\x07\x41piType\x12%\n\x17UNSUPPORTED_REST_LEGACY\x10\x00\x1a\x08\x08\x01\xa8\xf7\xb4\x8b\x02\x01\x12\x08\n\x04REST\x10\x01\x12\x08\n\x04GRPC\x10\x02\x12\x0e\n\nDELTA_GRPC\x10\x03\"\x18\n\x16\x41ggregatedConfigSource\"Z\n\x10SelfConfigSource\x12\x46\n\x15transport_api_version\x18\x01 \x01(\x0e\x32\x1d.envoy.api.v2.core.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"\x86\x01\n\x11RateLimitSettings\x12\x30\n\nmax_tokens\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12?\n\tfill_rate\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0e\xfa\x42\x0b\x12\t!\x00\x00\x00\x00\x00\x00\x00\x00\"\xef\x02\n\x0c\x43onfigSource\x12\x0e\n\x04path\x18\x01 \x01(\tH\x00\x12?\n\x11\x61pi_config_source\x18\x02 \x01(\x0b\x32\".envoy.api.v2.core.ApiConfigSourceH\x00\x12\x38\n\x03\x61\x64s\x18\x03 \x01(\x0b\x32).envoy.api.v2.core.AggregatedConfigSourceH\x00\x12\x33\n\x04self\x18\x05 \x01(\x0b\x32#.envoy.api.v2.core.SelfConfigSourceH\x00\x12\x38\n\x15initial_fetch_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x45\n\x14resource_api_version\x18\x06 \x01(\x0e\x32\x1d.envoy.api.v2.core.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x42\x1e\n\x17\x63onfig_source_specifier\x12\x03\xf8\x42\x01*.\n\nApiVersion\x12\x0c\n\x04\x41UTO\x10\x00\x1a\x02\x08\x01\x12\n\n\x02V2\x10\x01\x1a\x02\x08\x01\x12\x06\n\x02V3\x10\x02\x42\x94\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\x11\x43onfigSourceProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.config_source_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\021ConfigSourceProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _APIVERSION.values_by_name["AUTO"]._options = None
  _APIVERSION.values_by_name["AUTO"]._serialized_options = b'\010\001'
  _APIVERSION.values_by_name["V2"]._options = None
  _APIVERSION.values_by_name["V2"]._serialized_options = b'\010\001'
  _APICONFIGSOURCE_APITYPE.values_by_name["UNSUPPORTED_REST_LEGACY"]._options = None
  _APICONFIGSOURCE_APITYPE.values_by_name["UNSUPPORTED_REST_LEGACY"]._serialized_options = b'\010\001\250\367\264\213\002\001'
  _APICONFIGSOURCE.fields_by_name['api_type']._options = None
  _APICONFIGSOURCE.fields_by_name['api_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _APICONFIGSOURCE.fields_by_name['transport_api_version']._options = None
  _APICONFIGSOURCE.fields_by_name['transport_api_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _APICONFIGSOURCE.fields_by_name['request_timeout']._options = None
  _APICONFIGSOURCE.fields_by_name['request_timeout']._serialized_options = b'\372B\005\252\001\002*\000'
  _SELFCONFIGSOURCE.fields_by_name['transport_api_version']._options = None
  _SELFCONFIGSOURCE.fields_by_name['transport_api_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _RATELIMITSETTINGS.fields_by_name['fill_rate']._options = None
  _RATELIMITSETTINGS.fields_by_name['fill_rate']._serialized_options = b'\372B\013\022\t!\000\000\000\000\000\000\000\000'
  _CONFIGSOURCE.oneofs_by_name['config_source_specifier']._options = None
  _CONFIGSOURCE.oneofs_by_name['config_source_specifier']._serialized_options = b'\370B\001'
  _CONFIGSOURCE.fields_by_name['resource_api_version']._options = None
  _CONFIGSOURCE.fields_by_name['resource_api_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_APIVERSION']._serialized_start=1459
  _globals['_APIVERSION']._serialized_end=1505
  _globals['_APICONFIGSOURCE']._serialized_start=288
  _globals['_APICONFIGSOURCE']._serialized_end=832
  _globals['_APICONFIGSOURCE_APITYPE']._serialized_start=748
  _globals['_APICONFIGSOURCE_APITYPE']._serialized_end=832
  _globals['_AGGREGATEDCONFIGSOURCE']._serialized_start=834
  _globals['_AGGREGATEDCONFIGSOURCE']._serialized_end=858
  _globals['_SELFCONFIGSOURCE']._serialized_start=860
  _globals['_SELFCONFIGSOURCE']._serialized_end=950
  _globals['_RATELIMITSETTINGS']._serialized_start=953
  _globals['_RATELIMITSETTINGS']._serialized_end=1087
  _globals['_CONFIGSOURCE']._serialized_start=1090
  _globals['_CONFIGSOURCE']._serialized_end=1457
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/route/v3/scoped_route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.route.v3 import route_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(envoy/config/route/v3/scoped_route.proto\x12\x15\x65nvoy.config.route.v3\x1a!envoy/config/route/v3/route.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xd3\x04\n\x18ScopedRouteConfiguration\x12\x11\n\ton_demand\x18\x04 \x01(\x08\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x36\n\x18route_configuration_name\x18\x02 \x01(\tB\x14\xf2\x98\xfe\x8f\x05\x0e\x12\x0croute_config\x12\\\n\x13route_configuration\x18\x05 \x01(\x0b\x32).envoy.config.route.v3.RouteConfigurationB\x14\xf2\x98\xfe\x8f\x05\x0e\x12\x0croute_config\x12J\n\x03key\x18\x03 \x01(\x0b\x32\x33.envoy.config.route.v3.ScopedRouteConfiguration.KeyB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1a\xfc\x01\n\x03Key\x12Y\n\tfragments\x18\x01 \x03(\x0b\x32<.envoy.config.route.v3.ScopedRouteConfiguration.Key.FragmentB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1ah\n\x08\x46ragment\x12\x14\n\nstring_key\x18\x01 \x01(\tH\x00:9\x9a\xc5\x88\x1e\x34\n2envoy.api.v2.ScopedRouteConfiguration.Key.FragmentB\x0b\n\x04type\x12\x03\xf8\x42\x01:0\x9a\xc5\x88\x1e+\n)envoy.api.v2.ScopedRouteConfiguration.Key:,\x9a\xc5\x88\x1e\'\n%envoy.api.v2.ScopedRouteConfigurationB\x87\x01\n#io.envoyproxy.envoy.config.route.v3B\x10ScopedRouteProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/route/v3;routev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.route.v3.scoped_route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.config.route.v3B\020ScopedRouteProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/route/v3;routev3\272\200\310\321\006\002\020\002'
  _SCOPEDROUTECONFIGURATION_KEY_FRAGMENT.oneofs_by_name['type']._options = None
  _SCOPEDROUTECONFIGURATION_KEY_FRAGMENT.oneofs_by_name['type']._serialized_options = b'\370B\001'
  _SCOPEDROUTECONFIGURATION_KEY_FRAGMENT._options = None
  _SCOPEDROUTECONFIGURATION_KEY_FRAGMENT._serialized_options = b'\232\305\210\0364\n2envoy.api.v2.ScopedRouteConfiguration.Key.Fragment'
  _SCOPEDROUTECONFIGURATION_KEY.fields_by_name['fragments']._options = None
  _SCOPEDROUTECONFIGURATION_KEY.fields_by_name['fragments']._serialized_options = b'\372B\005\222\001\002\010\001'
  _SCOPEDROUTECONFIGURATION_KEY._options = None
  _SCOPEDROUTECONFIGURATION_KEY._serialized_options = b'\232\305\210\036+\n)envoy.api.v2.ScopedRouteConfiguration.Key'
  _SCOPEDROUTECONFIGURATION.fields_by_name['name']._options = None
  _SCOPEDROUTECONFIGURATION.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _SCOPEDROUTECONFIGURATION.fields_by_name['route_configuration_name']._options = None
  _SCOPEDROUTECONFIGURATION.fields_by_name['route_configuration_name']._serialized_options = b'\362\230\376\217\005\016\022\014route_config'
  _SCOPEDROUTECONFIGURATION.fields_by_name['route_configuration']._options = None
  _SCOPEDROUTECONFIGURATION.fields_by_name['route_configuration']._serialized_options = b'\362\230\376\217\005\016\022\014route_config'
  _SCOPEDROUTECONFIGURATION.fields_by_name['key']._options = None
  _SCOPEDROUTECONFIGURATION.fields_by_name['key']._serialized_options = b'\372B\005\212\001\002\020\001'
  _SCOPEDROUTECONFIGURATION._options = None
  _SCOPEDROUTECONFIGURATION._serialized_options = b'\232\305\210\036\'\n%envoy.api.v2.ScopedRouteConfiguration'
  _globals['_SCOPEDROUTECONFIGURATION']._serialized_start=226
  _globals['_SCOPEDROUTECONFIGURATION']._serialized_end=821
  _globals['_SCOPEDROUTECONFIGURATION_KEY']._serialized_start=523
  _globals['_SCOPEDROUTECONFIGURATION_KEY']._serialized_end=775
  _globals['_SCOPEDROUTECONFIGURATION_KEY_FRAGMENT']._serialized_start=621
  _globals['_SCOPEDROUTECONFIGURATION_KEY_FRAGMENT']._serialized_end=725
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1beta1/decl.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1beta1 import expr_pb2 as google_dot_api_dot_expr_dot_v1beta1_dot_expr__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"google/api/expr/v1beta1/decl.proto\x12\x17google.api.expr.v1beta1\x1a\"google/api/expr/v1beta1/expr.proto\"\xa5\x01\n\x04\x44\x65\x63l\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03\x64oc\x18\x03 \x01(\t\x12\x33\n\x05ident\x18\x04 \x01(\x0b\x32\".google.api.expr.v1beta1.IdentDeclH\x00\x12\x39\n\x08\x66unction\x18\x05 \x01(\x0b\x32%.google.api.expr.v1beta1.FunctionDeclH\x00\x42\x06\n\x04kind\"\\\n\x08\x44\x65\x63lType\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x36\n\x0btype_params\x18\x04 \x03(\x0b\x32!.google.api.expr.v1beta1.DeclType\"j\n\tIdentDecl\x12/\n\x04type\x18\x03 \x01(\x0b\x32!.google.api.expr.v1beta1.DeclType\x12,\n\x05value\x18\x04 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.Expr\"\x93\x01\n\x0c\x46unctionDecl\x12\x30\n\x04\x61rgs\x18\x01 \x03(\x0b\x32\".google.api.expr.v1beta1.IdentDecl\x12\x36\n\x0breturn_type\x18\x02 \x01(\x0b\x32!.google.api.expr.v1beta1.DeclType\x12\x19\n\x11receiver_function\x18\x03 \x01(\x08\x42j\n\x1b\x63om.google.api.expr.v1beta1B\tDeclProtoP\x01Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1beta1.decl_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.google.api.expr.v1beta1B\tDeclProtoP\001Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\370\001\001'
  _globals['_DECL']._serialized_start=100
  _globals['_DECL']._serialized_end=265
  _globals['_DECLTYPE']._serialized_start=267
  _globals['_DECLTYPE']._serialized_end=359
  _globals['_IDENTDECL']._serialized_start=361
  _globals['_IDENTDECL']._serialized_end=467
  _globals['_FUNCTIONDECL']._serialized_start=470
  _globals['_FUNCTIONDECL']._serialized_end=617
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/localized_text.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n google/type/localized_text.proto\x12\x0bgoogle.type\"4\n\rLocalizedText\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x15\n\rlanguage_code\x18\x02 \x01(\tBz\n\x0f\x63om.google.typeB\x12LocalizedTextProtoP\x01ZHgoogle.golang.org/genproto/googleapis/type/localized_text;localized_text\xf8\x01\x01\xa2\x02\x03GTPb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.localized_text_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017com.google.typeB\022LocalizedTextProtoP\001ZHgoogle.golang.org/genproto/googleapis/type/localized_text;localized_text\370\001\001\242\002\003GTP'
  _globals['_LOCALIZEDTEXT']._serialized_start=49
  _globals['_LOCALIZEDTEXT']._serialized_end=101
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/grpc_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'envoy/config/core/v3/grpc_service.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xa5\x1c\n\x0bGrpcService\x12\x41\n\nenvoy_grpc\x18\x01 \x01(\x0b\x32+.envoy.config.core.v3.GrpcService.EnvoyGrpcH\x00\x12\x43\n\x0bgoogle_grpc\x18\x02 \x01(\x0b\x32,.envoy.config.core.v3.GrpcService.GoogleGrpcH\x00\x12*\n\x07timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12;\n\x10initial_metadata\x18\x05 \x03(\x0b\x32!.envoy.config.core.v3.HeaderValue\x1a\xb9\x01\n\tEnvoyGrpc\x12\x1d\n\x0c\x63luster_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12$\n\tauthority\x18\x02 \x01(\tB\x11\xfa\x42\x0er\x0c\x10\x00(\x80\x80\x01\xc0\x01\x02\xc8\x01\x00\x12\x37\n\x0cretry_policy\x18\x03 \x01(\x0b\x32!.envoy.config.core.v3.RetryPolicy:.\x9a\xc5\x88\x1e)\n\'envoy.api.v2.core.GrpcService.EnvoyGrpc\x1a\xa3\x18\n\nGoogleGrpc\x12\x1b\n\ntarget_uri\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\\\n\x13\x63hannel_credentials\x18\x02 \x01(\x0b\x32?.envoy.config.core.v3.GrpcService.GoogleGrpc.ChannelCredentials\x12V\n\x10\x63\x61ll_credentials\x18\x03 \x03(\x0b\x32<.envoy.config.core.v3.GrpcService.GoogleGrpc.CallCredentials\x12\x1c\n\x0bstat_prefix\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12 \n\x18\x63redentials_factory_name\x18\x05 \x01(\t\x12\'\n\x06\x63onfig\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\x1dper_stream_buffer_limit_bytes\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12N\n\x0c\x63hannel_args\x18\x08 \x01(\x0b\x32\x38.envoy.config.core.v3.GrpcService.GoogleGrpc.ChannelArgs\x1a\xfb\x01\n\x0eSslCredentials\x12\x34\n\nroot_certs\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12=\n\x0bprivate_key\x18\x02 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x34\n\ncert_chain\x18\x03 \x01(\x0b\x32 .envoy.config.core.v3.DataSource:>\x9a\xc5\x88\x1e\x39\n7envoy.api.v2.core.GrpcService.GoogleGrpc.SslCredentials\x1a`\n\x16GoogleLocalCredentials:F\x9a\xc5\x88\x1e\x41\n?envoy.api.v2.core.GrpcService.GoogleGrpc.GoogleLocalCredentials\x1a\xe1\x02\n\x12\x43hannelCredentials\x12V\n\x0fssl_credentials\x18\x01 \x01(\x0b\x32;.envoy.config.core.v3.GrpcService.GoogleGrpc.SslCredentialsH\x00\x12\x30\n\x0egoogle_default\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12`\n\x11local_credentials\x18\x03 \x01(\x0b\x32\x43.envoy.config.core.v3.GrpcService.GoogleGrpc.GoogleLocalCredentialsH\x00:B\x9a\xc5\x88\x1e=\n;envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentialsB\x1b\n\x14\x63redential_specifier\x12\x03\xf8\x42\x01\x1a\xb1\x0c\n\x0f\x43\x61llCredentials\x12\x16\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tH\x00\x12\x37\n\x15google_compute_engine\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x1e\n\x14google_refresh_token\x18\x03 \x01(\tH\x00\x12\x85\x01\n\x1aservice_account_jwt_access\x18\x04 \x01(\x0b\x32_.envoy.config.core.v3.GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentialsH\x00\x12g\n\ngoogle_iam\x18\x05 \x01(\x0b\x32Q.envoy.config.core.v3.GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentialsH\x00\x12q\n\x0b\x66rom_plugin\x18\x06 \x01(\x0b\x32Z.envoy.config.core.v3.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPluginH\x00\x12^\n\x0bsts_service\x18\x07 \x01(\x0b\x32G.envoy.config.core.v3.GrpcService.GoogleGrpc.CallCredentials.StsServiceH\x00\x1a\xba\x01\n\"ServiceAccountJWTAccessCredentials\x12\x10\n\x08json_key\x18\x01 \x01(\t\x12\x1e\n\x16token_lifetime_seconds\x18\x02 \x01(\x04:b\x9a\xc5\x88\x1e]\n[envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentials\x1a\xa5\x01\n\x14GoogleIAMCredentials\x12\x1b\n\x13\x61uthorization_token\x18\x01 \x01(\t\x12\x1a\n\x12\x61uthority_selector\x18\x02 \x01(\t:T\x9a\xc5\x88\x1eO\nMenvoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentials\x1a\xd7\x01\n\x1dMetadataCredentialsFromPlugin\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:]\x9a\xc5\x88\x1eX\nVenvoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPluginB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\x1a\xcb\x02\n\nStsService\x12\"\n\x1atoken_exchange_service_uri\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\x12\x10\n\x08\x61udience\x18\x03 \x01(\t\x12\r\n\x05scope\x18\x04 \x01(\t\x12\x1c\n\x14requested_token_type\x18\x05 \x01(\t\x12#\n\x12subject_token_path\x18\x06 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12#\n\x12subject_token_type\x18\x07 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x10\x61\x63tor_token_path\x18\x08 \x01(\t\x12\x18\n\x10\x61\x63tor_token_type\x18\t \x01(\t:J\x9a\xc5\x88\x1e\x45\nCenvoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService:?\x9a\xc5\x88\x1e:\n8envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentialsB\x1b\n\x14\x63redential_specifier\x12\x03\xf8\x42\x01\x1a\x9a\x02\n\x0b\x43hannelArgs\x12P\n\x04\x61rgs\x18\x01 \x03(\x0b\x32\x42.envoy.config.core.v3.GrpcService.GoogleGrpc.ChannelArgs.ArgsEntry\x1aL\n\x05Value\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x42\x16\n\x0fvalue_specifier\x12\x03\xf8\x42\x01\x1ak\n\tArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12M\n\x05value\x18\x02 \x01(\x0b\x32>.envoy.config.core.v3.GrpcService.GoogleGrpc.ChannelArgs.Value:\x02\x38\x01:/\x9a\xc5\x88\x1e*\n(envoy.api.v2.core.GrpcService.GoogleGrpc:$\x9a\xc5\x88\x1e\x1f\n\x1d\x65nvoy.api.v2.core.GrpcServiceB\x17\n\x10target_specifier\x12\x03\xf8\x42\x01J\x04\x08\x04\x10\x05\x42\x84\x01\n\"io.envoyproxy.envoy.config.core.v3B\x10GrpcServiceProtoP\x01ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.core.v3.grpc_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.envoyproxy.envoy.config.core.v3B\020GrpcServiceProtoP\001ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\272\200\310\321\006\002\020\002'
  _GRPCSERVICE_ENVOYGRPC.fields_by_name['cluster_name']._options = None
  _GRPCSERVICE_ENVOYGRPC.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002\020\001'
  _GRPCSERVICE_ENVOYGRPC.fields_by_name['authority']._options = None
  _GRPCSERVICE_ENVOYGRPC.fields_by_name['authority']._serialized_options = b'\372B\016r\014\020\000(\200\200\001\300\001\002\310\001\000'
  _GRPCSERVICE_ENVOYGRPC._options = None
  _GRPCSERVICE_ENVOYGRPC._serialized_options = b'\232\305\210\036)\n\'envoy.api.v2.core.GrpcService.EnvoyGrpc'
  _GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS.fields_by_name['private_key']._options = None
  _GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS.fields_by_name['private_key']._serialized_options = b'\270\267\213\244\002\001'
  _GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS._options = None
  _GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS._serialized_options = b'\232\305\210\0369\n7envoy.api.v2.core.GrpcService.GoogleGrpc.SslCredentials'
  _GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS._options = None
  _GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS._serialized_options = b'\232\305\210\036A\n?envoy.api.v2.core.GrpcService.GoogleGrpc.GoogleLocalCredentials'
  _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier']._options = None
  _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier']._serialized_options = b'\370B\001'
  _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS._options = None
  _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS._serialized_options = b'\232\305\210\036=\n;envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials'
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS._options = None
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS._serialized_options = b'\232\305\210\036]\n[envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentials'
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS._options = None
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS._serialized_options = b'\232\305\210\036O\nMenvoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentials'
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN._options = None
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN._serialized_options = b'\232\305\210\036X\nVenvoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPlugin'
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.fields_by_name['subject_token_path']._options = None
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.fields_by_name['subject_token_path']._serialized_options = b'\372B\004r\002\020\001'
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.fields_by_name['subject_token_type']._options = None
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.fields_by_name['subject_token_type']._serialized_options = b'\372B\004r\002\020\001'
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE._options = None
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE._serialized_options = b'\232\305\210\036E\nCenvoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService'
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']._options = None
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']._serialized_options = b'\370B\001'
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS._options = None
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS._serialized_options = b'\232\305\210\036:\n8envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials'
  _GRPCSERVICE_GOOGLEGRPC_CHANNELARGS_VALUE.oneofs_by_name['value_specifier']._options = None
  _GRPCSERVICE_GOOGLEGRPC_CHANNELARGS_VALUE.oneofs_by_name['value_specifier']._serialized_options = b'\370B\001'
  _GRPCSERVICE_GOOGLEGRPC_CHANNELARGS_ARGSENTRY._options = None
  _GRPCSERVICE_GOOGLEGRPC_CHANNELARGS_ARGSENTRY._serialized_options = b'8\001'
  _GRPCSERVICE_GOOGLEGRPC.fields_by_name['target_uri']._options = None
  _GRPCSERVICE_GOOGLEGRPC.fields_by_name['target_uri']._serialized_options = b'\372B\004r\002\020\001'
  _GRPCSERVICE_GOOGLEGRPC.fields_by_name['stat_prefix']._options = None
  _GRPCSERVICE_GOOGLEGRPC.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _GRPCSERVICE_GOOGLEGRPC._options = None
  _GRPCSERVICE_GOOGLEGRPC._serialized_options = b'\232\305\210\036*\n(envoy.api.v2.core.GrpcService.GoogleGrpc'
  _GRPCSERVICE.oneofs_by_name['target_specifier']._options = None
  _GRPCSERVICE.oneofs_by_name['target_specifier']._serialized_options = b'\370B\001'
  _GRPCSERVICE._options = None
  _GRPCSERVICE._serialized_options = b'\232\305\210\036\037\n\035envoy.api.v2.core.GrpcService'
  _globals['_GRPCSERVICE']._serialized_start=374
  _globals['_GRPCSERVICE']._serialized_end=3995
  _globals['_GRPCSERVICE_ENVOYGRPC']._serialized_start=631
  _globals['_GRPCSERVICE_ENVOYGRPC']._serialized_end=816
  _globals['_GRPCSERVICE_GOOGLEGRPC']._serialized_start=819
  _globals['_GRPCSERVICE_GOOGLEGRPC']._serialized_end=3926
  _globals['_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS']._serialized_start=1299
  _globals['_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS']._serialized_end=1550
  _globals['_GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS']._serialized_start=1552
  _globals['_GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS']._serialized_end=1648
  _globals['_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS']._serialized_start=1651
  _globals['_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS']._serialized_end=2004
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS']._serialized_start=2007
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS']._serialized_end=3592
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS']._serialized_start=2592
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS']._serialized_end=2778
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS']._serialized_start=2781
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS']._serialized_end=2946
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN']._serialized_start=2949
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN']._serialized_end=3164
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE']._serialized_start=3167
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE']._serialized_end=3498
  _globals['_GRPCSERVICE_GOOGLEGRPC_CHANNELARGS']._serialized_start=3595
  _globals['_GRPCSERVICE_GOOGLEGRPC_CHANNELARGS']._serialized_end=3877
  _globals['_GRPCSERVICE_GOOGLEGRPC_CHANNELARGS_VALUE']._serialized_start=3692
  _globals['_GRPCSERVICE_GOOGLEGRPC_CHANNELARGS_VALUE']._serialized_end=3768
  _globals['_GRPCSERVICE_GOOGLEGRPC_CHANNELARGS_ARGSENTRY']._serialized_start=3770
  _globals['_GRPCSERVICE_GOOGLEGRPC_CHANNELARGS_ARGSENTRY']._serialized_end=3877
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/auth/v3/external_auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.service.auth.v3 import attribute_context_pb2 as envoy_dot_service_dot_auth_dot_v3_dot_attribute__context__pb2
from envoy.type.v3 import http_status_pb2 as envoy_dot_type_dot_v3_dot_http__status__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)envoy/service/auth/v3/external_auth.proto\x12\x15\x65nvoy.service.auth.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a-envoy/service/auth/v3/attribute_context.proto\x1a\x1f\x65nvoy/type/v3/http_status.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x17google/rpc/status.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"v\n\x0c\x43heckRequest\x12;\n\nattributes\x18\x01 \x01(\x0b\x32\'.envoy.service.auth.v3.AttributeContext:)\x9a\xc5\x88\x1e$\n\"envoy.service.auth.v2.CheckRequest\"\xb8\x01\n\x12\x44\x65niedHttpResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x19.envoy.type.v3.HttpStatus\x12\x38\n\x07headers\x18\x02 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOption\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t:/\x9a\xc5\x88\x1e*\n(envoy.service.auth.v2.DeniedHttpResponse\"\x87\x03\n\x0eOkHttpResponse\x12\x38\n\x07headers\x18\x02 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOption\x12\x19\n\x11headers_to_remove\x18\x05 \x03(\t\x12>\n\x10\x64ynamic_metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12H\n\x17response_headers_to_add\x18\x06 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOption\x12\x45\n\x17query_parameters_to_set\x18\x07 \x03(\x0b\x32$.envoy.config.core.v3.QueryParameter\x12\"\n\x1aquery_parameters_to_remove\x18\x08 \x03(\t:+\x9a\xc5\x88\x1e&\n$envoy.service.auth.v2.OkHttpResponse\"\xa7\x02\n\rCheckResponse\x12\"\n\x06status\x18\x01 \x01(\x0b\x32\x12.google.rpc.Status\x12\x44\n\x0f\x64\x65nied_response\x18\x02 \x01(\x0b\x32).envoy.service.auth.v3.DeniedHttpResponseH\x00\x12<\n\x0bok_response\x18\x03 \x01(\x0b\x32%.envoy.service.auth.v3.OkHttpResponseH\x00\x12\x31\n\x10\x64ynamic_metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct:*\x9a\xc5\x88\x1e%\n#envoy.service.auth.v2.CheckResponseB\x0f\n\rhttp_response2e\n\rAuthorization\x12T\n\x05\x43heck\x12#.envoy.service.auth.v3.CheckRequest\x1a$.envoy.service.auth.v3.CheckResponse\"\x00\x42\x87\x01\n#io.envoyproxy.envoy.service.auth.v3B\x11\x45xternalAuthProtoP\x01ZCgithub.com/envoyproxy/go-control-plane/envoy/service/auth/v3;authv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.auth.v3.external_auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.service.auth.v3B\021ExternalAuthProtoP\001ZCgithub.com/envoyproxy/go-control-plane/envoy/service/auth/v3;authv3\272\200\310\321\006\002\020\002'
  _CHECKREQUEST._options = None
  _CHECKREQUEST._serialized_options = b'\232\305\210\036$\n\"envoy.service.auth.v2.CheckRequest'
  _DENIEDHTTPRESPONSE._options = None
  _DENIEDHTTPRESPONSE._serialized_options = b'\232\305\210\036*\n(envoy.service.auth.v2.DeniedHttpResponse'
  _OKHTTPRESPONSE.fields_by_name['dynamic_metadata']._options = None
  _OKHTTPRESPONSE.fields_by_name['dynamic_metadata']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _OKHTTPRESPONSE._options = None
  _OKHTTPRESPONSE._serialized_options = b'\232\305\210\036&\n$envoy.service.auth.v2.OkHttpResponse'
  _CHECKRESPONSE._options = None
  _CHECKRESPONSE._serialized_options = b'\232\305\210\036%\n#envoy.service.auth.v2.CheckResponse'
  _globals['_CHECKREQUEST']._serialized_start=339
  _globals['_CHECKREQUEST']._serialized_end=457
  _globals['_DENIEDHTTPRESPONSE']._serialized_start=460
  _globals['_DENIEDHTTPRESPONSE']._serialized_end=644
  _globals['_OKHTTPRESPONSE']._serialized_start=647
  _globals['_OKHTTPRESPONSE']._serialized_end=1038
  _globals['_CHECKRESPONSE']._serialized_start=1041
  _globals['_CHECKRESPONSE']._serialized_end=1336
  _globals['_AUTHORIZATION']._serialized_start=1338
  _globals['_AUTHORIZATION']._serialized_end=1439
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/ratelimit/v3/rate_limit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.ratelimit.v3 import rls_pb2 as envoy_dot_config_dot_ratelimit_dot_v3_dot_rls__pb2
from envoy.extensions.common.ratelimit.v3 import ratelimit_pb2 as envoy_dot_extensions_dot_common_dot_ratelimit_dot_v3_dot_ratelimit__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>envoy/extensions/filters/network/ratelimit/v3/rate_limit.proto\x12-envoy.extensions.filters.network.ratelimit.v3\x1a#envoy/config/ratelimit/v3/rls.proto\x1a\x34\x65nvoy/extensions/common/ratelimit/v3/ratelimit.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xf8\x02\n\tRateLimit\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x06\x64omain\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12X\n\x0b\x64\x65scriptors\x18\x03 \x03(\x0b\x32\x39.envoy.extensions.common.ratelimit.v3.RateLimitDescriptorB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12*\n\x07timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x19\n\x11\x66\x61ilure_mode_deny\x18\x05 \x01(\x08\x12W\n\x12rate_limit_service\x18\x06 \x01(\x0b\x32\x31.envoy.config.ratelimit.v3.RateLimitServiceConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01::\x9a\xc5\x88\x1e\x35\n3envoy.config.filter.network.rate_limit.v2.RateLimitB\xb9\x01\n;io.envoyproxy.envoy.extensions.filters.network.ratelimit.v3B\x0eRateLimitProtoP\x01Z`github.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/ratelimit/v3;ratelimitv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.ratelimit.v3.rate_limit_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n;io.envoyproxy.envoy.extensions.filters.network.ratelimit.v3B\016RateLimitProtoP\001Z`github.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/ratelimit/v3;ratelimitv3\272\200\310\321\006\002\020\002'
  _RATELIMIT.fields_by_name['stat_prefix']._options = None
  _RATELIMIT.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _RATELIMIT.fields_by_name['domain']._options = None
  _RATELIMIT.fields_by_name['domain']._serialized_options = b'\372B\004r\002\020\001'
  _RATELIMIT.fields_by_name['descriptors']._options = None
  _RATELIMIT.fields_by_name['descriptors']._serialized_options = b'\372B\005\222\001\002\010\001'
  _RATELIMIT.fields_by_name['rate_limit_service']._options = None
  _RATELIMIT.fields_by_name['rate_limit_service']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RATELIMIT._options = None
  _RATELIMIT._serialized_options = b'\232\305\210\0365\n3envoy.config.filter.network.rate_limit.v2.RateLimit'
  _globals['_RATELIMIT']._serialized_start=328
  _globals['_RATELIMIT']._serialized_end=704
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.cluster.v3 import cluster_pb2 as envoy_dot_config_dot_cluster_dot_v3_dot_cluster__pb2
from envoy.config.common.key_value.v3 import config_pb2 as envoy_dot_config_dot_common_dot_key__value_dot_v3_dot_config__pb2
from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.core.v3 import resolver_pb2 as envoy_dot_config_dot_core_dot_v3_dot_resolver__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto\x12\x30\x65nvoy.extensions.common.dynamic_forward_proxy.v3\x1a%envoy/config/cluster/v3/cluster.proto\x1a-envoy/config/common/key_value/v3/config.proto\x1a\"envoy/config/core/v3/address.proto\x1a$envoy/config/core/v3/extension.proto\x1a#envoy/config/core/v3/resolver.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"U\n\x17\x44nsCacheCircuitBreakers\x12:\n\x14max_pending_requests\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"\xa6\x08\n\x0e\x44nsCacheConfig\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12U\n\x11\x64ns_lookup_family\x18\x02 \x01(\x0e\x32\x30.envoy.config.cluster.v3.Cluster.DnsLookupFamilyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x41\n\x10\x64ns_refresh_rate\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06\x32\x04\x10\xc0\x84=\x12\x43\n\x14\x64ns_min_refresh_rate\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08\x05\x12\x35\n\x08host_ttl\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x38\n\tmax_hosts\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12N\n\x18\x64ns_failure_refresh_rate\x18\x06 \x01(\x0b\x32,.envoy.config.cluster.v3.Cluster.RefreshRate\x12l\n\x19\x64ns_cache_circuit_breaker\x18\x07 \x01(\x0b\x32I.envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheCircuitBreakers\x12,\n\x17use_tcp_for_dns_lookups\x18\x08 \x01(\x08\x42\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12U\n\x15\x64ns_resolution_config\x18\t \x01(\x0b\x32).envoy.config.core.v3.DnsResolutionConfigB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12M\n\x19typed_dns_resolver_config\x18\x0c \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12\x41\n\x14preresolve_hostnames\x18\n \x03(\x0b\x32#.envoy.config.core.v3.SocketAddress\x12>\n\x11\x64ns_query_timeout\x18\x0b \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12O\n\x10key_value_config\x18\r \x01(\x0b\x32\x35.envoy.config.common.key_value.v3.KeyValueStoreConfig:G\x9a\xc5\x88\x1e\x42\n@envoy.config.common.dynamic_forward_proxy.v2alpha.DnsCacheConfigB\xca\x01\n>io.envoyproxy.envoy.extensions.common.dynamic_forward_proxy.v3B\rDnsCacheProtoP\x01Zogithub.com/envoyproxy/go-control-plane/envoy/extensions/common/dynamic_forward_proxy/v3;dynamic_forward_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.common.dynamic_forward_proxy.v3.dns_cache_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>io.envoyproxy.envoy.extensions.common.dynamic_forward_proxy.v3B\rDnsCacheProtoP\001Zogithub.com/envoyproxy/go-control-plane/envoy/extensions/common/dynamic_forward_proxy/v3;dynamic_forward_proxyv3\272\200\310\321\006\002\020\002'
  _DNSCACHECONFIG.fields_by_name['name']._options = None
  _DNSCACHECONFIG.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _DNSCACHECONFIG.fields_by_name['dns_lookup_family']._options = None
  _DNSCACHECONFIG.fields_by_name['dns_lookup_family']._serialized_options = b'\372B\005\202\001\002\020\001'
  _DNSCACHECONFIG.fields_by_name['dns_refresh_rate']._options = None
  _DNSCACHECONFIG.fields_by_name['dns_refresh_rate']._serialized_options = b'\372B\t\252\001\0062\004\020\300\204='
  _DNSCACHECONFIG.fields_by_name['dns_min_refresh_rate']._options = None
  _DNSCACHECONFIG.fields_by_name['dns_min_refresh_rate']._serialized_options = b'\372B\007\252\001\0042\002\010\005'
  _DNSCACHECONFIG.fields_by_name['host_ttl']._options = None
  _DNSCACHECONFIG.fields_by_name['host_ttl']._serialized_options = b'\372B\005\252\001\002*\000'
  _DNSCACHECONFIG.fields_by_name['max_hosts']._options = None
  _DNSCACHECONFIG.fields_by_name['max_hosts']._serialized_options = b'\372B\004*\002 \000'
  _DNSCACHECONFIG.fields_by_name['use_tcp_for_dns_lookups']._options = None
  _DNSCACHECONFIG.fields_by_name['use_tcp_for_dns_lookups']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _DNSCACHECONFIG.fields_by_name['dns_resolution_config']._options = None
  _DNSCACHECONFIG.fields_by_name['dns_resolution_config']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _DNSCACHECONFIG.fields_by_name['dns_query_timeout']._options = None
  _DNSCACHECONFIG.fields_by_name['dns_query_timeout']._serialized_options = b'\372B\005\252\001\002*\000'
  _DNSCACHECONFIG._options = None
  _DNSCACHECONFIG._serialized_options = b'\232\305\210\036B\n@envoy.config.common.dynamic_forward_proxy.v2alpha.DnsCacheConfig'
  _globals['_DNSCACHECIRCUITBREAKERS']._serialized_start=507
  _globals['_DNSCACHECIRCUITBREAKERS']._serialized_end=592
  _globals['_DNSCACHECONFIG']._serialized_start=595
  _globals['_DNSCACHECONFIG']._serialized_end=1657
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/auth/cert.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from envoy.api.v2.auth import common_pb2 as envoy_dot_api_dot_v2_dot_auth_dot_common__pb2
from envoy.api.v2.auth import secret_pb2 as envoy_dot_api_dot_v2_dot_auth_dot_secret__pb2
from envoy.api.v2.auth import tls_pb2 as envoy_dot_api_dot_v2_dot_auth_dot_tls__pb2

from envoy.api.v2.auth.common_pb2 import *
from envoy.api.v2.auth.secret_pb2 import *
from envoy.api.v2.auth.tls_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65nvoy/api/v2/auth/cert.proto\x12\x11\x65nvoy.api.v2.auth\x1a\x1eudpa/annotations/migrate.proto\x1a\x1e\x65nvoy/api/v2/auth/common.proto\x1a\x1e\x65nvoy/api/v2/auth/secret.proto\x1a\x1b\x65nvoy/api/v2/auth/tls.protoB\x99\x01\n\x1fio.envoyproxy.envoy.api.v2.authB\tCertProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/auth\xf2\x98\xfe\x8f\x05+\x12)envoy.extensions.transport_sockets.tls.v3P\x01P\x02P\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.auth.cert_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.authB\tCertProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/auth\362\230\376\217\005+\022)envoy.extensions.transport_sockets.tls.v3'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v3/http_tracer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'envoy/config/trace/v3/http_tracer.proto\x12\x15\x65nvoy.config.trace.v3\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xf8\x01\n\x07Tracing\x12\x31\n\x04http\x18\x01 \x01(\x0b\x32#.envoy.config.trace.v3.Tracing.Http\x1a\x93\x01\n\x04Http\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:)\x9a\xc5\x88\x1e$\n\"envoy.config.trace.v2.Tracing.HttpB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig:$\x9a\xc5\x88\x1e\x1f\n\x1d\x65nvoy.config.trace.v2.TracingB\x86\x01\n#io.envoyproxy.envoy.config.trace.v3B\x0fHttpTracerProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v3.http_tracer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v3B\017HttpTracerProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\272\200\310\321\006\002\020\002'
  _TRACING_HTTP.fields_by_name['name']._options = None
  _TRACING_HTTP.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _TRACING_HTTP._options = None
  _TRACING_HTTP._serialized_options = b'\232\305\210\036$\n\"envoy.config.trace.v2.Tracing.Http'
  _TRACING._options = None
  _TRACING._serialized_options = b'\232\305\210\036\037\n\035envoy.config.trace.v2.Tracing'
  _globals['_TRACING']._serialized_start=185
  _globals['_TRACING']._serialized_end=433
  _globals['_TRACING_HTTP']._serialized_start=248
  _globals['_TRACING_HTTP']._serialized_end=395
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/gzip/v2/gzip.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.filter.http.compressor.v2 import compressor_pb2 as envoy_dot_config_dot_filter_dot_http_dot_compressor_dot_v2_dot_compressor__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+envoy/config/filter/http/gzip/v2/gzip.proto\x12 envoy.config.filter.http.gzip.v2\x1a\x37\x65nvoy/config/filter/http/compressor/v2/compressor.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xbb\x05\n\x04Gzip\x12=\n\x0cmemory_level\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\t(\x01\x12\x38\n\x0e\x63ontent_length\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x02\x18\x01\x12\x61\n\x11\x63ompression_level\x18\x03 \x01(\x0e\x32<.envoy.config.filter.http.gzip.v2.Gzip.CompressionLevel.EnumB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x62\n\x14\x63ompression_strategy\x18\x04 \x01(\x0e\x32:.envoy.config.filter.http.gzip.v2.Gzip.CompressionStrategyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x18\n\x0c\x63ontent_type\x18\x06 \x03(\tB\x02\x18\x01\x12\"\n\x16\x64isable_on_etag_header\x18\x07 \x01(\x08\x42\x02\x18\x01\x12)\n\x1dremove_accept_encoding_header\x18\x08 \x01(\x08\x42\x02\x18\x01\x12<\n\x0bwindow_bits\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\x0f(\t\x12\x46\n\ncompressor\x18\n \x01(\x0b\x32\x32.envoy.config.filter.http.compressor.v2.Compressor\x1a<\n\x10\x43ompressionLevel\"(\n\x04\x45num\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04\x42\x45ST\x10\x01\x12\t\n\x05SPEED\x10\x02\"F\n\x13\x43ompressionStrategy\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0c\n\x08\x46ILTERED\x10\x01\x12\x0b\n\x07HUFFMAN\x10\x02\x12\x07\n\x03RLE\x10\x03\x42\xc2\x01\n.io.envoyproxy.envoy.config.filter.http.gzip.v2B\tGzipProtoP\x01ZNgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/gzip/v2;gzipv2\xf2\x98\xfe\x8f\x05\'\x12%envoy.extensions.filters.http.gzip.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.gzip.v2.gzip_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.io.envoyproxy.envoy.config.filter.http.gzip.v2B\tGzipProtoP\001ZNgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/gzip/v2;gzipv2\362\230\376\217\005\'\022%envoy.extensions.filters.http.gzip.v3\272\200\310\321\006\002\020\001'
  _GZIP.fields_by_name['memory_level']._options = None
  _GZIP.fields_by_name['memory_level']._serialized_options = b'\372B\006*\004\030\t(\001'
  _GZIP.fields_by_name['content_length']._options = None
  _GZIP.fields_by_name['content_length']._serialized_options = b'\030\001'
  _GZIP.fields_by_name['compression_level']._options = None
  _GZIP.fields_by_name['compression_level']._serialized_options = b'\372B\005\202\001\002\020\001'
  _GZIP.fields_by_name['compression_strategy']._options = None
  _GZIP.fields_by_name['compression_strategy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _GZIP.fields_by_name['content_type']._options = None
  _GZIP.fields_by_name['content_type']._serialized_options = b'\030\001'
  _GZIP.fields_by_name['disable_on_etag_header']._options = None
  _GZIP.fields_by_name['disable_on_etag_header']._serialized_options = b'\030\001'
  _GZIP.fields_by_name['remove_accept_encoding_header']._options = None
  _GZIP.fields_by_name['remove_accept_encoding_header']._serialized_options = b'\030\001'
  _GZIP.fields_by_name['window_bits']._options = None
  _GZIP.fields_by_name['window_bits']._serialized_options = b'\372B\006*\004\030\017(\t'
  _globals['_GZIP']._serialized_start=259
  _globals['_GZIP']._serialized_end=958
  _globals['_GZIP_COMPRESSIONLEVEL']._serialized_start=826
  _globals['_GZIP_COMPRESSIONLEVEL']._serialized_end=886
  _globals['_GZIP_COMPRESSIONLEVEL_ENUM']._serialized_start=846
  _globals['_GZIP_COMPRESSIONLEVEL_ENUM']._serialized_end=886
  _globals['_GZIP_COMPRESSIONSTRATEGY']._serialized_start=888
  _globals['_GZIP_COMPRESSIONSTRATEGY']._serialized_end=958
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/event_service_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/envoy/config/core/v3/event_service_config.proto\x12\x14\x65nvoy.config.core.v3\x1a\'envoy/config/core/v3/grpc_service.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9c\x01\n\x12\x45ventServiceConfig\x12\x39\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceH\x00:+\x9a\xc5\x88\x1e&\n$envoy.api.v2.core.EventServiceConfigB\x1e\n\x17\x63onfig_source_specifier\x12\x03\xf8\x42\x01\x42\x8b\x01\n\"io.envoyproxy.envoy.config.core.v3B\x17\x45ventServiceConfigProtoP\x01ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.core.v3.event_service_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.envoyproxy.envoy.config.core.v3B\027EventServiceConfigProtoP\001ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\272\200\310\321\006\002\020\002'
  _EVENTSERVICECONFIG.oneofs_by_name['config_source_specifier']._options = None
  _EVENTSERVICECONFIG.oneofs_by_name['config_source_specifier']._serialized_options = b'\370B\001'
  _EVENTSERVICECONFIG._options = None
  _EVENTSERVICECONFIG._serialized_options = b'\232\305\210\036&\n$envoy.api.v2.core.EventServiceConfig'
  _globals['_EVENTSERVICECONFIG']._serialized_start=206
  _globals['_EVENTSERVICECONFIG']._serialized_end=362
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opentelemetry/proto/trace/v1/trace.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opentelemetry.proto.common.v1 import common_pb2 as opentelemetry_dot_proto_dot_common_dot_v1_dot_common__pb2
from opentelemetry.proto.resource.v1 import resource_pb2 as opentelemetry_dot_proto_dot_resource_dot_v1_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(opentelemetry/proto/trace/v1/trace.proto\x12\x1copentelemetry.proto.trace.v1\x1a*opentelemetry/proto/common/v1/common.proto\x1a.opentelemetry/proto/resource/v1/resource.proto\"\xc2\x01\n\rResourceSpans\x12;\n\x08resource\x18\x01 \x01(\x0b\x32).opentelemetry.proto.resource.v1.Resource\x12`\n\x1dinstrumentation_library_spans\x18\x02 \x03(\x0b\x32\x39.opentelemetry.proto.trace.v1.InstrumentationLibrarySpans\x12\x12\n\nschema_url\x18\x03 \x01(\t\"\xbc\x01\n\x1bInstrumentationLibrarySpans\x12V\n\x17instrumentation_library\x18\x01 \x01(\x0b\x32\x35.opentelemetry.proto.common.v1.InstrumentationLibrary\x12\x31\n\x05spans\x18\x02 \x03(\x0b\x32\".opentelemetry.proto.trace.v1.Span\x12\x12\n\nschema_url\x18\x03 \x01(\t\"\xe6\x07\n\x04Span\x12\x10\n\x08trace_id\x18\x01 \x01(\x0c\x12\x0f\n\x07span_id\x18\x02 \x01(\x0c\x12\x13\n\x0btrace_state\x18\x03 \x01(\t\x12\x16\n\x0eparent_span_id\x18\x04 \x01(\x0c\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x39\n\x04kind\x18\x06 \x01(\x0e\x32+.opentelemetry.proto.trace.v1.Span.SpanKind\x12\x1c\n\x14start_time_unix_nano\x18\x07 \x01(\x06\x12\x1a\n\x12\x65nd_time_unix_nano\x18\x08 \x01(\x06\x12;\n\nattributes\x18\t \x03(\x0b\x32\'.opentelemetry.proto.common.v1.KeyValue\x12 \n\x18\x64ropped_attributes_count\x18\n \x01(\r\x12\x38\n\x06\x65vents\x18\x0b \x03(\x0b\x32(.opentelemetry.proto.trace.v1.Span.Event\x12\x1c\n\x14\x64ropped_events_count\x18\x0c \x01(\r\x12\x36\n\x05links\x18\r \x03(\x0b\x32\'.opentelemetry.proto.trace.v1.Span.Link\x12\x1b\n\x13\x64ropped_links_count\x18\x0e \x01(\r\x12\x34\n\x06status\x18\x0f \x01(\x0b\x32$.opentelemetry.proto.trace.v1.Status\x1a\x8c\x01\n\x05\x45vent\x12\x16\n\x0etime_unix_nano\x18\x01 \x01(\x06\x12\x0c\n\x04name\x18\x02 \x01(\t\x12;\n\nattributes\x18\x03 \x03(\x0b\x32\'.opentelemetry.proto.common.v1.KeyValue\x12 \n\x18\x64ropped_attributes_count\x18\x04 \x01(\r\x1a\x9d\x01\n\x04Link\x12\x10\n\x08trace_id\x18\x01 \x01(\x0c\x12\x0f\n\x07span_id\x18\x02 \x01(\x0c\x12\x13\n\x0btrace_state\x18\x03 \x01(\t\x12;\n\nattributes\x18\x04 \x03(\x0b\x32\'.opentelemetry.proto.common.v1.KeyValue\x12 \n\x18\x64ropped_attributes_count\x18\x05 \x01(\r\"\x99\x01\n\x08SpanKind\x12\x19\n\x15SPAN_KIND_UNSPECIFIED\x10\x00\x12\x16\n\x12SPAN_KIND_INTERNAL\x10\x01\x12\x14\n\x10SPAN_KIND_SERVER\x10\x02\x12\x14\n\x10SPAN_KIND_CLIENT\x10\x03\x12\x16\n\x12SPAN_KIND_PRODUCER\x10\x04\x12\x16\n\x12SPAN_KIND_CONSUMER\x10\x05\"\xdd\x07\n\x06Status\x12V\n\x0f\x64\x65precated_code\x18\x01 \x01(\x0e\x32\x39.opentelemetry.proto.trace.v1.Status.DeprecatedStatusCodeB\x02\x18\x01\x12\x0f\n\x07message\x18\x02 \x01(\t\x12=\n\x04\x63ode\x18\x03 \x01(\x0e\x32/.opentelemetry.proto.trace.v1.Status.StatusCode\"\xda\x05\n\x14\x44\x65precatedStatusCode\x12\x1d\n\x19\x44\x45PRECATED_STATUS_CODE_OK\x10\x00\x12$\n DEPRECATED_STATUS_CODE_CANCELLED\x10\x01\x12(\n$DEPRECATED_STATUS_CODE_UNKNOWN_ERROR\x10\x02\x12+\n\'DEPRECATED_STATUS_CODE_INVALID_ARGUMENT\x10\x03\x12,\n(DEPRECATED_STATUS_CODE_DEADLINE_EXCEEDED\x10\x04\x12$\n DEPRECATED_STATUS_CODE_NOT_FOUND\x10\x05\x12)\n%DEPRECATED_STATUS_CODE_ALREADY_EXISTS\x10\x06\x12,\n(DEPRECATED_STATUS_CODE_PERMISSION_DENIED\x10\x07\x12-\n)DEPRECATED_STATUS_CODE_RESOURCE_EXHAUSTED\x10\x08\x12.\n*DEPRECATED_STATUS_CODE_FAILED_PRECONDITION\x10\t\x12\"\n\x1e\x44\x45PRECATED_STATUS_CODE_ABORTED\x10\n\x12\'\n#DEPRECATED_STATUS_CODE_OUT_OF_RANGE\x10\x0b\x12(\n$DEPRECATED_STATUS_CODE_UNIMPLEMENTED\x10\x0c\x12)\n%DEPRECATED_STATUS_CODE_INTERNAL_ERROR\x10\r\x12&\n\"DEPRECATED_STATUS_CODE_UNAVAILABLE\x10\x0e\x12$\n DEPRECATED_STATUS_CODE_DATA_LOSS\x10\x0f\x12*\n&DEPRECATED_STATUS_CODE_UNAUTHENTICATED\x10\x10\"N\n\nStatusCode\x12\x15\n\x11STATUS_CODE_UNSET\x10\x00\x12\x12\n\x0eSTATUS_CODE_OK\x10\x01\x12\x15\n\x11STATUS_CODE_ERROR\x10\x02\x42n\n\x1fio.opentelemetry.proto.trace.v1B\nTraceProtoP\x01Z=github.com/open-telemetry/opentelemetry-proto/gen/go/trace/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opentelemetry.proto.trace.v1.trace_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.opentelemetry.proto.trace.v1B\nTraceProtoP\001Z=github.com/open-telemetry/opentelemetry-proto/gen/go/trace/v1'
  _STATUS.fields_by_name['deprecated_code']._options = None
  _STATUS.fields_by_name['deprecated_code']._serialized_options = b'\030\001'
  _globals['_RESOURCESPANS']._serialized_start=167
  _globals['_RESOURCESPANS']._serialized_end=361
  _globals['_INSTRUMENTATIONLIBRARYSPANS']._serialized_start=364
  _globals['_INSTRUMENTATIONLIBRARYSPANS']._serialized_end=552
  _globals['_SPAN']._serialized_start=555
  _globals['_SPAN']._serialized_end=1553
  _globals['_SPAN_EVENT']._serialized_start=1097
  _globals['_SPAN_EVENT']._serialized_end=1237
  _globals['_SPAN_LINK']._serialized_start=1240
  _globals['_SPAN_LINK']._serialized_end=1397
  _globals['_SPAN_SPANKIND']._serialized_start=1400
  _globals['_SPAN_SPANKIND']._serialized_end=1553
  _globals['_STATUS']._serialized_start=1556
  _globals['_STATUS']._serialized_end=2545
  _globals['_STATUS_DEPRECATEDSTATUSCODE']._serialized_start=1735
  _globals['_STATUS_DEPRECATEDSTATUSCODE']._serialized_end=2465
  _globals['_STATUS_STATUSCODE']._serialized_start=2467
  _globals['_STATUS_STATUSCODE']._serialized_end=2545
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/rate_limit_descriptors/expr/v3/expr.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1alpha1 import syntax_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:envoy/extensions/rate_limit_descriptors/expr/v3/expr.proto\x12/envoy.extensions.rate_limit_descriptors.expr.v3\x1a%google/api/expr/v1alpha1/syntax.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa1\x01\n\nDescriptor\x12\x1f\n\x0e\x64\x65scriptor_key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\rskip_if_error\x18\x02 \x01(\x08\x12\x17\n\x04text\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x30\n\x06parsed\x18\x04 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprH\x00\x42\x10\n\x0e\x65xpr_specifierB\xb3\x01\n=io.envoyproxy.envoy.extensions.rate_limit_descriptors.expr.v3B\tExprProtoP\x01Z]github.com/envoyproxy/go-control-plane/envoy/extensions/rate_limit_descriptors/expr/v3;exprv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.rate_limit_descriptors.expr.v3.expr_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n=io.envoyproxy.envoy.extensions.rate_limit_descriptors.expr.v3B\tExprProtoP\001Z]github.com/envoyproxy/go-control-plane/envoy/extensions/rate_limit_descriptors/expr/v3;exprv3\272\200\310\321\006\002\020\002'
  _DESCRIPTOR.fields_by_name['descriptor_key']._options = None
  _DESCRIPTOR.fields_by_name['descriptor_key']._serialized_options = b'\372B\004r\002\020\001'
  _DESCRIPTOR.fields_by_name['text']._options = None
  _DESCRIPTOR.fields_by_name['text']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DESCRIPTOR']._serialized_start=207
  _globals['_DESCRIPTOR']._serialized_end=368
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/ext_authz/v3/ext_authz.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from envoy.type.matcher.v3 import metadata_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_metadata__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=envoy/extensions/filters/network/ext_authz/v3/ext_authz.proto\x12-envoy.extensions.filters.network.ext_authz.v3\x1a(envoy/config/core/v3/config_source.proto\x1a\'envoy/config/core/v3/grpc_service.proto\x1a$envoy/type/matcher/v3/metadata.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x94\x03\n\x08\x45xtAuthz\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x37\n\x0cgrpc_service\x18\x02 \x01(\x0b\x32!.envoy.config.core.v3.GrpcService\x12\x1a\n\x12\x66\x61ilure_mode_allow\x18\x03 \x01(\x08\x12 \n\x18include_peer_certificate\x18\x04 \x01(\x08\x12I\n\x15transport_api_version\x18\x05 \x01(\x0e\x32 .envoy.config.core.v3.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12G\n\x17\x66ilter_enabled_metadata\x18\x06 \x01(\x0b\x32&.envoy.type.matcher.v3.MetadataMatcher\x12%\n\x1d\x62ootstrap_metadata_labels_key\x18\x07 \x01(\t:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.network.ext_authz.v2.ExtAuthzB\xb8\x01\n;io.envoyproxy.envoy.extensions.filters.network.ext_authz.v3B\rExtAuthzProtoP\x01Z`github.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/ext_authz/v3;ext_authzv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.ext_authz.v3.ext_authz_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n;io.envoyproxy.envoy.extensions.filters.network.ext_authz.v3B\rExtAuthzProtoP\001Z`github.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/ext_authz/v3;ext_authzv3\272\200\310\321\006\002\020\002'
  _EXTAUTHZ.fields_by_name['stat_prefix']._options = None
  _EXTAUTHZ.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _EXTAUTHZ.fields_by_name['transport_api_version']._options = None
  _EXTAUTHZ.fields_by_name['transport_api_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _EXTAUTHZ._options = None
  _EXTAUTHZ._serialized_options = b'\232\305\210\0363\n1envoy.config.filter.network.ext_authz.v2.ExtAuthz'
  _globals['_EXTAUTHZ']._serialized_start=325
  _globals['_EXTAUTHZ']._serialized_end=729
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/composite/v3/composite.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:envoy/extensions/filters/http/composite/v3/composite.proto\x12*envoy.extensions.filters.http.composite.v3\x1a(envoy/config/core/v3/config_source.proto\x1a$envoy/config/core/v3/extension.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x0b\n\tComposite\"m\n\rDynamicConfig\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x45\n\x10\x63onfig_discovery\x18\x02 \x01(\x0b\x32+.envoy.config.core.v3.ExtensionConfigSource\"\xd4\x01\n\x13\x45xecuteFilterAction\x12U\n\x0ctyped_config\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x13\xf2\x98\xfe\x8f\x05\r\x12\x0b\x63onfig_type\x12\x66\n\x0e\x64ynamic_config\x18\x02 \x01(\x0b\x32\x39.envoy.extensions.filters.http.composite.v3.DynamicConfigB\x13\xf2\x98\xfe\x8f\x05\r\x12\x0b\x63onfig_typeB\xb3\x01\n8io.envoyproxy.envoy.extensions.filters.http.composite.v3B\x0e\x43ompositeProtoP\x01Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/composite/v3;compositev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.composite.v3.composite_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8io.envoyproxy.envoy.extensions.filters.http.composite.v3B\016CompositeProtoP\001Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/composite/v3;compositev3\272\200\310\321\006\002\020\002'
  _DYNAMICCONFIG.fields_by_name['name']._options = None
  _DYNAMICCONFIG.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _EXECUTEFILTERACTION.fields_by_name['typed_config']._options = None
  _EXECUTEFILTERACTION.fields_by_name['typed_config']._serialized_options = b'\362\230\376\217\005\r\022\013config_type'
  _EXECUTEFILTERACTION.fields_by_name['dynamic_config']._options = None
  _EXECUTEFILTERACTION.fields_by_name['dynamic_config']._serialized_options = b'\362\230\376\217\005\r\022\013config_type'
  _globals['_COMPOSITE']._serialized_start=274
  _globals['_COMPOSITE']._serialized_end=285
  _globals['_DYNAMICCONFIG']._serialized_start=287
  _globals['_DYNAMICCONFIG']._serialized_end=396
  _globals['_EXECUTEFILTERACTION']._serialized_start=399
  _globals['_EXECUTEFILTERACTION']._serialized_end=611
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/rate_limit_quota/v3/rlqs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import ratelimit_strategy_pb2 as envoy_dot_type_dot_v3_dot_ratelimit__strategy__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,envoy/service/rate_limit_quota/v3/rlqs.proto\x12!envoy.service.rate_limit_quota.v3\x1a&envoy/type/v3/ratelimit_strategy.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x83\x03\n\x1aRateLimitQuotaUsageReports\x12\x17\n\x06\x64omain\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12u\n\x13\x62ucket_quota_usages\x18\x02 \x03(\x0b\x32N.envoy.service.rate_limit_quota.v3.RateLimitQuotaUsageReports.BucketQuotaUsageB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xd4\x01\n\x10\x42ucketQuotaUsage\x12H\n\tbucket_id\x18\x01 \x01(\x0b\x32+.envoy.service.rate_limit_quota.v3.BucketIdB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12;\n\x0ctime_elapsed\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x12\x1c\n\x14num_requests_allowed\x18\x03 \x01(\x04\x12\x1b\n\x13num_requests_denied\x18\x04 \x01(\x04\"\x93\x05\n\x16RateLimitQuotaResponse\x12g\n\rbucket_action\x18\x01 \x03(\x0b\x32\x46.envoy.service.rate_limit_quota.v3.RateLimitQuotaResponse.BucketActionB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x8f\x04\n\x0c\x42ucketAction\x12H\n\tbucket_id\x18\x01 \x01(\x0b\x32+.envoy.service.rate_limit_quota.v3.BucketIdB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x7f\n\x17quota_assignment_action\x18\x02 \x01(\x0b\x32\\.envoy.service.rate_limit_quota.v3.RateLimitQuotaResponse.BucketAction.QuotaAssignmentActionH\x00\x12n\n\x0e\x61\x62\x61ndon_action\x18\x03 \x01(\x0b\x32T.envoy.service.rate_limit_quota.v3.RateLimitQuotaResponse.BucketAction.AbandonActionH\x00\x1a\x9c\x01\n\x15QuotaAssignmentAction\x12\x44\n\x17\x61ssignment_time_to_live\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02\x32\x00\x12=\n\x13rate_limit_strategy\x18\x03 \x01(\x0b\x32 .envoy.type.v3.RateLimitStrategy\x1a\x0f\n\rAbandonActionB\x14\n\rbucket_action\x12\x03\xf8\x42\x01\"\x98\x01\n\x08\x42ucketId\x12]\n\x06\x62ucket\x18\x01 \x03(\x0b\x32\x37.envoy.service.rate_limit_quota.v3.BucketId.BucketEntryB\x14\xfa\x42\x11\x9a\x01\x0e\x08\x01\"\x04r\x02\x10\x01*\x04r\x02\x10\x01\x1a-\n\x0b\x42ucketEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32\xb1\x01\n\x15RateLimitQuotaService\x12\x97\x01\n\x15StreamRateLimitQuotas\x12=.envoy.service.rate_limit_quota.v3.RateLimitQuotaUsageReports\x1a\x39.envoy.service.rate_limit_quota.v3.RateLimitQuotaResponse\"\x00(\x01\x30\x01\x42\xab\x01\n/io.envoyproxy.envoy.service.rate_limit_quota.v3B\tRlqsProtoP\x01Z[github.com/envoyproxy/go-control-plane/envoy/service/rate_limit_quota/v3;rate_limit_quotav3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.rate_limit_quota.v3.rlqs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n/io.envoyproxy.envoy.service.rate_limit_quota.v3B\tRlqsProtoP\001Z[github.com/envoyproxy/go-control-plane/envoy/service/rate_limit_quota/v3;rate_limit_quotav3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _RATELIMITQUOTAUSAGEREPORTS_BUCKETQUOTAUSAGE.fields_by_name['bucket_id']._options = None
  _RATELIMITQUOTAUSAGEREPORTS_BUCKETQUOTAUSAGE.fields_by_name['bucket_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RATELIMITQUOTAUSAGEREPORTS_BUCKETQUOTAUSAGE.fields_by_name['time_elapsed']._options = None
  _RATELIMITQUOTAUSAGEREPORTS_BUCKETQUOTAUSAGE.fields_by_name['time_elapsed']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _RATELIMITQUOTAUSAGEREPORTS.fields_by_name['domain']._options = None
  _RATELIMITQUOTAUSAGEREPORTS.fields_by_name['domain']._serialized_options = b'\372B\004r\002\020\001'
  _RATELIMITQUOTAUSAGEREPORTS.fields_by_name['bucket_quota_usages']._options = None
  _RATELIMITQUOTAUSAGEREPORTS.fields_by_name['bucket_quota_usages']._serialized_options = b'\372B\005\222\001\002\010\001'
  _RATELIMITQUOTARESPONSE_BUCKETACTION_QUOTAASSIGNMENTACTION.fields_by_name['assignment_time_to_live']._options = None
  _RATELIMITQUOTARESPONSE_BUCKETACTION_QUOTAASSIGNMENTACTION.fields_by_name['assignment_time_to_live']._serialized_options = b'\372B\005\252\001\0022\000'
  _RATELIMITQUOTARESPONSE_BUCKETACTION.oneofs_by_name['bucket_action']._options = None
  _RATELIMITQUOTARESPONSE_BUCKETACTION.oneofs_by_name['bucket_action']._serialized_options = b'\370B\001'
  _RATELIMITQUOTARESPONSE_BUCKETACTION.fields_by_name['bucket_id']._options = None
  _RATELIMITQUOTARESPONSE_BUCKETACTION.fields_by_name['bucket_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RATELIMITQUOTARESPONSE.fields_by_name['bucket_action']._options = None
  _RATELIMITQUOTARESPONSE.fields_by_name['bucket_action']._serialized_options = b'\372B\005\222\001\002\010\001'
  _BUCKETID_BUCKETENTRY._options = None
  _BUCKETID_BUCKETENTRY._serialized_options = b'8\001'
  _BUCKETID.fields_by_name['bucket']._options = None
  _BUCKETID.fields_by_name['bucket']._serialized_options = b'\372B\021\232\001\016\010\001\"\004r\002\020\001*\004r\002\020\001'
  _globals['_RATELIMITQUOTAUSAGEREPORTS']._serialized_start=245
  _globals['_RATELIMITQUOTAUSAGEREPORTS']._serialized_end=632
  _globals['_RATELIMITQUOTAUSAGEREPORTS_BUCKETQUOTAUSAGE']._serialized_start=420
  _globals['_RATELIMITQUOTAUSAGEREPORTS_BUCKETQUOTAUSAGE']._serialized_end=632
  _globals['_RATELIMITQUOTARESPONSE']._serialized_start=635
  _globals['_RATELIMITQUOTARESPONSE']._serialized_end=1294
  _globals['_RATELIMITQUOTARESPONSE_BUCKETACTION']._serialized_start=767
  _globals['_RATELIMITQUOTARESPONSE_BUCKETACTION']._serialized_end=1294
  _globals['_RATELIMITQUOTARESPONSE_BUCKETACTION_QUOTAASSIGNMENTACTION']._serialized_start=1099
  _globals['_RATELIMITQUOTARESPONSE_BUCKETACTION_QUOTAASSIGNMENTACTION']._serialized_end=1255
  _globals['_RATELIMITQUOTARESPONSE_BUCKETACTION_ABANDONACTION']._serialized_start=1257
  _globals['_RATELIMITQUOTARESPONSE_BUCKETACTION_ABANDONACTION']._serialized_end=1272
  _globals['_BUCKETID']._serialized_start=1297
  _globals['_BUCKETID']._serialized_end=1449
  _globals['_BUCKETID_BUCKETENTRY']._serialized_start=1404
  _globals['_BUCKETID_BUCKETENTRY']._serialized_end=1449
  _globals['_RATELIMITQUOTASERVICE']._serialized_start=1452
  _globals['_RATELIMITQUOTASERVICE']._serialized_end=1629
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/matching/input_matchers/consistent_hashing/v3/consistent_hashing.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nWenvoy/extensions/matching/input_matchers/consistent_hashing/v3/consistent_hashing.proto\x12>envoy.extensions.matching.input_matchers.consistent_hashing.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"M\n\x11\x43onsistentHashing\x12\x11\n\tthreshold\x18\x01 \x01(\r\x12\x17\n\x06modulo\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02 \x00\x12\x0c\n\x04seed\x18\x03 \x01(\x04\x42\xec\x01\nLio.envoyproxy.envoy.extensions.matching.input_matchers.consistent_hashing.v3B\x16\x43onsistentHashingProtoP\x01Zzgithub.com/envoyproxy/go-control-plane/envoy/extensions/matching/input_matchers/consistent_hashing/v3;consistent_hashingv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.matching.input_matchers.consistent_hashing.v3.consistent_hashing_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nLio.envoyproxy.envoy.extensions.matching.input_matchers.consistent_hashing.v3B\026ConsistentHashingProtoP\001Zzgithub.com/envoyproxy/go-control-plane/envoy/extensions/matching/input_matchers/consistent_hashing/v3;consistent_hashingv3\272\200\310\321\006\002\020\002'
  _CONSISTENTHASHING.fields_by_name['modulo']._options = None
  _CONSISTENTHASHING.fields_by_name['modulo']._serialized_options = b'\372B\004*\002 \000'
  _globals['_CONSISTENTHASHING']._serialized_start=211
  _globals['_CONSISTENTHASHING']._serialized_end=288
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v3/server_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n envoy/admin/v3/server_info.proto\x12\x0e\x65nvoy.admin.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xb6\x03\n\nServerInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\x12/\n\x05state\x18\x02 \x01(\x0e\x32 .envoy.admin.v3.ServerInfo.State\x12\x37\n\x14uptime_current_epoch\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x34\n\x11uptime_all_epochs\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1b\n\x13hot_restart_version\x18\x05 \x01(\t\x12@\n\x14\x63ommand_line_options\x18\x06 \x01(\x0b\x32\".envoy.admin.v3.CommandLineOptions\x12(\n\x04node\x18\x07 \x01(\x0b\x32\x1a.envoy.config.core.v3.Node\"G\n\x05State\x12\x08\n\x04LIVE\x10\x00\x12\x0c\n\x08\x44RAINING\x10\x01\x12\x14\n\x10PRE_INITIALIZING\x10\x02\x12\x10\n\x0cINITIALIZING\x10\x03:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.admin.v2alpha.ServerInfo\"\xbf\n\n\x12\x43ommandLineOptions\x12\x0f\n\x07\x62\x61se_id\x18\x01 \x01(\x04\x12\x1b\n\x13use_dynamic_base_id\x18\x1f \x01(\x08\x12\x14\n\x0c\x62\x61se_id_path\x18  \x01(\t\x12\x13\n\x0b\x63oncurrency\x18\x02 \x01(\r\x12\x13\n\x0b\x63onfig_path\x18\x03 \x01(\t\x12\x13\n\x0b\x63onfig_yaml\x18\x04 \x01(\t\x12#\n\x1b\x61llow_unknown_static_fields\x18\x05 \x01(\x08\x12%\n\x1dreject_unknown_dynamic_fields\x18\x1a \x01(\x08\x12%\n\x1dignore_unknown_dynamic_fields\x18\x1e \x01(\x08\x12\x1a\n\x12\x61\x64min_address_path\x18\x06 \x01(\t\x12N\n\x18local_address_ip_version\x18\x07 \x01(\x0e\x32,.envoy.admin.v3.CommandLineOptions.IpVersion\x12\x11\n\tlog_level\x18\x08 \x01(\t\x12\x1b\n\x13\x63omponent_log_level\x18\t \x01(\t\x12\x12\n\nlog_format\x18\n \x01(\t\x12\x1a\n\x12log_format_escaped\x18\x1b \x01(\x08\x12\x10\n\x08log_path\x18\x0b \x01(\t\x12\x17\n\x0fservice_cluster\x18\r \x01(\t\x12\x14\n\x0cservice_node\x18\x0e \x01(\t\x12\x14\n\x0cservice_zone\x18\x0f \x01(\t\x12\x36\n\x13\x66ile_flush_interval\x18\x10 \x01(\x0b\x32\x19.google.protobuf.Duration\x12-\n\ndrain_time\x18\x11 \x01(\x0b\x32\x19.google.protobuf.Duration\x12H\n\x0e\x64rain_strategy\x18! \x01(\x0e\x32\x30.envoy.admin.v3.CommandLineOptions.DrainStrategy\x12\x37\n\x14parent_shutdown_time\x18\x12 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\x04mode\x18\x13 \x01(\x0e\x32\'.envoy.admin.v3.CommandLineOptions.Mode\x12\x1b\n\x13\x64isable_hot_restart\x18\x16 \x01(\x08\x12\x1c\n\x14\x65nable_mutex_tracing\x18\x17 \x01(\x08\x12\x15\n\rrestart_epoch\x18\x18 \x01(\r\x12\x16\n\x0e\x63puset_threads\x18\x19 \x01(\x08\x12\x1b\n\x13\x64isabled_extensions\x18\x1c \x03(\t\x12!\n\x19\x65nable_fine_grain_logging\x18\" \x01(\x08\x12\x13\n\x0bsocket_path\x18# \x01(\t\x12\x13\n\x0bsocket_mode\x18$ \x01(\r\x12\x18\n\x10\x65nable_core_dump\x18% \x01(\x08\x12\x11\n\tstats_tag\x18& \x03(\t\"\x1b\n\tIpVersion\x12\x06\n\x02v4\x10\x00\x12\x06\n\x02v6\x10\x01\"-\n\x04Mode\x12\t\n\x05Serve\x10\x00\x12\x0c\n\x08Validate\x10\x01\x12\x0c\n\x08InitOnly\x10\x02\"+\n\rDrainStrategy\x12\x0b\n\x07Gradual\x10\x00\x12\r\n\tImmediate\x10\x01:-\x9a\xc5\x88\x1e(\n&envoy.admin.v2alpha.CommandLineOptionsJ\x04\x08\x0c\x10\rJ\x04\x08\x14\x10\x15J\x04\x08\x15\x10\x16J\x04\x08\x1d\x10\x1eR\tmax_statsR\x10max_obj_name_lenR\x11\x62ootstrap_versionBx\n\x1cio.envoyproxy.envoy.admin.v3B\x0fServerInfoProtoP\x01Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v3.server_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034io.envoyproxy.envoy.admin.v3B\017ServerInfoProtoP\001Z=github.com/envoyproxy/go-control-plane/envoy/admin/v3;adminv3\272\200\310\321\006\002\020\002'
  _SERVERINFO._options = None
  _SERVERINFO._serialized_options = b'\232\305\210\036 \n\036envoy.admin.v2alpha.ServerInfo'
  _COMMANDLINEOPTIONS._options = None
  _COMMANDLINEOPTIONS._serialized_options = b'\232\305\210\036(\n&envoy.admin.v2alpha.CommandLineOptions'
  _globals['_SERVERINFO']._serialized_start=184
  _globals['_SERVERINFO']._serialized_end=622
  _globals['_SERVERINFO_STATE']._serialized_start=512
  _globals['_SERVERINFO_STATE']._serialized_end=583
  _globals['_COMMANDLINEOPTIONS']._serialized_start=625
  _globals['_COMMANDLINEOPTIONS']._serialized_end=1968
  _globals['_COMMANDLINEOPTIONS_IPVERSION']._serialized_start=1730
  _globals['_COMMANDLINEOPTIONS_IPVERSION']._serialized_end=1757
  _globals['_COMMANDLINEOPTIONS_MODE']._serialized_start=1759
  _globals['_COMMANDLINEOPTIONS_MODE']._serialized_end=1804
  _globals['_COMMANDLINEOPTIONS_DRAINSTRATEGY']._serialized_start=1806
  _globals['_COMMANDLINEOPTIONS_DRAINSTRATEGY']._serialized_end=1849
# @@protoc_insertion_point(module_scope)
